@@ -35,10 +35,16 @@
 
 /* Debug statement handler */
 #ifdef DEBUG
+#ifdef TARGET_RISCOS
+#define DEBUGFUNCMSGIN if (basicvars.debug_flags.functions) printf(">>> Entered function %s:%s at line %d\n", __FILE__, __func__, __LINE__)
+#define DEBUGFUNCMSGOUT if (basicvars.debug_flags.functions) printf("<<< Exited function  %s:%s at line %d\n", __FILE__, __func__, __LINE__)
+#define DEBUGFUNCMSG(x) if (basicvars.debug_flags.functions) printf("    %s:%s: %s at line %d\n", __FILE__, __func__, x, __LINE__)
+#else
 #define DEBUGFUNCMSGIN if (basicvars.debug_flags.functions) fprintf(stderr, ">>> Entered function %s:%s at line %d\n", __FILE__, __func__, __LINE__)
 #define DEBUGFUNCMSGOUT if (basicvars.debug_flags.functions) fprintf(stderr, "<<< Exited function  %s:%s at line %d\n", __FILE__, __func__, __LINE__)
 #define DEBUGFUNCMSG(x) if (basicvars.debug_flags.functions) fprintf(stderr, "    %s:%s: %s at line %d\n", __FILE__, __func__, x, __LINE__)
-#else
+#endif
+#else /* DEBUG */
 /* Not debugging, these macros resolve to nothing */
 #define DEBUGFUNCMSGIN
 #define DEBUGFUNCMSGOUT
@@ -93,7 +99,8 @@
 #define DEBUG_STACK 0x2000      /* Show structures pushed and popped from stack */
 #define DEBUG_ALLSTACK 0x4000   /* Show in detail items pushed and popped from stack */
 #define DEBUG_FUNCTIONS 0x8000  /* Show which functions are called - very incomplete */
-#define DEBUG_VDU 0x10000       /* Ghow debugging related to VDU drivers */
+#define DEBUG_VDU 0x10000       /* Show debugging related to VDU drivers */
+#define DEBUG_SOUND 0x20000     /* Show sound subsystem debugging */
 
 /* Variable type flags */
 
@@ -552,6 +559,7 @@ typedef struct {
     unsigned int allstack:1;  /* Show detailed stack push/pop info */
     unsigned int functions:1; /* Show functions entered (incomplete) */
     unsigned int vdu:1;       /* Show VDU debugging */
+    unsigned int sound:1;     /* Show sound system debugging */
   } debug_flags;              /* Interpreter debugging options */
 #endif
   struct {
@@ -621,6 +629,7 @@ typedef struct {
   SDL_Surface *surface;       /* SDL Surface handle for screen0 */
   int32 sdl_flags;            /* SDL surface flags */
   uint32 vdu14lines;          /* Line counter for VDU14 page mode */
+  uint32 videoscale;          /* Video scaling factor (1 or 2) */
   boolean noupdate;           /* Skip update if TRUE */
   boolean videothreadbusy;    /* True when thread is doing stuff */
   boolean cursorbusy;         /* TRUE when cursor is being worked on */
