@@ -344,7 +344,7 @@ static void gpio_init() {
 static void init2(void) {
   if (!mos_init() || !kbd_init() || !init_screen()) {
     cmderror(CMD_INITFAIL);           /* Initialisation failed */
-    exit_interpreter(EXIT_FAILURE);   /* End run */
+    exit_interpreter_real(EXIT_FAILURE);   /* End run */
   }
   if (!init_heap() || !init_workspace(worksize)) {
     cmderror(CMD_NOMEMORY);           /* Not enough memory to run interpreter */
@@ -400,10 +400,8 @@ static void check_configfile() {
     free(conffname);
     return;
   }
-  while (!feof(conffile)) {
-    memset(line,0,1024);          /* Clear the buffer before new entries are read */
+  while (fgets(line, 1024, conffile)!=NULL) {
     parameter=NULL;
-    fgets(line, 1024, conffile);
     /* Borrow the 'item' pointer, to remove any trailing CR/LF */
     item=strchr(line, '\n');
     if (item) *item='\0';
