@@ -153,7 +153,6 @@ static void handle_signal(int signo) {
 #ifdef TARGET_MINGW
     (void) signal(SIGCONT, handle_signal);
 #endif
-//    kbd_init();               // shouldn't be re-init'ing kbd in middle of a signal
     return;
 #endif
   default:
@@ -376,6 +375,7 @@ void show_help(void) {
   printf("  -fullscreen    Start Brandy in fullscreen mode\n");
   printf("  -nofull        Never use fullscreen mode\n");
   printf("  -swsurface     Use a software SDL surface\n");
+  printf("  -zoom <amount> Zoom display by <amount>:1\n");
 #endif
 #if !defined(TARGET_RISCOS) && !defined(TARGET_MINGW) && !defined(USE_SDL)
   printf("  -tek           Enable Tek graphics (on compatible builds)\n");
@@ -458,65 +458,41 @@ static detail errortable [] = {
 /* ERR_UNSUPSTATE */    {FATAL,    NOPARM,    0, "Unsupported Basic V/VI statement type found"},
 /* ERR_NOGRAPHICS */    {FATAL,    NOPARM,    0, "This version of the interpreter does not support graphics"},
 /* ERR_NOVDUCMDS */     {FATAL,    NOPARM,    0, "VDU commands cannot be used as output is not to a screen"},
-/* ERR_SYNTAX */        {NONFATAL, NOPARM,   16, "Syntax error"},
 /* ERR_SILLY */         {NONFATAL, NOPARM,    0, "Silly!"},
 /* ERR_BADPROG */       {NONFATAL, NOPARM,    0, "Bad program"},
-/* ERR_ESCAPE */        {NONFATAL, NOPARM,   17, "Escape"},
 /* ERR_STOP */          {FATAL,    NOPARM,    0, "STOP"},
 /* ERR_STATELEN */      {NONFATAL, NOPARM,    0, "Line is longer than 1024 characters"},
 /* ERR_LINENO */        {NONFATAL, NOPARM,    0, "Line number is outside the range 0..65279"},
-/* ERR_LINEMISS */      {NONFATAL, INTEGER,  41, "Cannot find line %d"},
-/* ERR_VARMISS */       {NONFATAL, STRING,   26, "Cannot find variable '%s'"},
-/* ERR_ARRAYMISS */     {NONFATAL, STRING,   14, "Cannot find array '%s)'"},
-/* ERR_FNMISS */        {NONFATAL, STRING,   29, "Cannot find function 'FN%s'"},
-/* ERR_PROCMISS */      {NONFATAL, STRING,   29, "Cannot find procedure 'PROC%s'"},
-/* ERR_TOOMANY */       {NONFATAL, BSTRING,  31, "There are too many parameters in the call to '%s'"},
-/* ERR_NOTENUFF */      {NONFATAL, BSTRING,  31, "There are not enough parameters in the call to '%s'"},
-/* ERR_BADDIM */        {NONFATAL, STRING,   11, "There is not enough memory to create array '%s)'"},
-/* ERR_BADBYTEDIM */    {NONFATAL, STRING,   11, "There is not enough memory to create a byte array"},
-/* ERR_NEGDIM */        {NONFATAL, STRING,   10, "Dimension of array '%s)' is negative"},
-/* ERR_NEGBYTEDIM */    {NONFATAL, STRING,   10, "Dimension of byte array '%s' is negative"},
-/* ERR_DIMCOUNT */      {NONFATAL, STRING,   10, "Array '%s)' has too many dimensions"},
-/* ERR_DUPLDIM */       {NONFATAL, STRING,   10, "Array '%s)' has already been created"},
-/* ERR_BADINDEX */      {NONFATAL, INTSTR,   15, "Array index value of %d is out of range in reference to '%s)'"},
-/* ERR_INDEXCO */       {NONFATAL, STRING,   15, "Number of array indexes in reference to '%s)' is wrong"},
-/* ERR_DIMRANGE */      {NONFATAL, NOPARM,   15, "The dimension number in call to 'DIM()' is out of range"},
-/* ERR_NODIMS */        {NONFATAL, STRING,   14, "The dimensions of array '%s)' have not been defined"},
-/* ERR_ADDRESS */       {NONFATAL, NOPARM,  242, "Address is out of range for given variable type"},
-/* WARN_BADTOKEN */     {WARNING,  NOPARM,    0, "Value entered is not a legal token value"},
-/* WARN_BADHEX */       {WARNING,  NOPARM,   28, "Warning: bad hexadecimal constant"},
-/* WARN_BADBIN */       {WARNING,  NOPARM,   28, "Warning: bad binary constant"},
-/* WARN_EXPOFLO */      {WARNING,  NOPARM,   20, "Warning: exponent is too large"},
 /* ERR_NAMEMISS */      {NONFATAL, NOPARM,    0, "Variable name expected"},
-/* ERR_EQMISS */        {NONFATAL, NOPARM,    4, "Mistake"},
-/* ERR_COMISS */        {NONFATAL, NOPARM,   27, "Missing ','"},
-/* ERR_LPMISS */        {NONFATAL, NOPARM,   27, "Missing '('"},
-/* ERR_RPMISS */        {NONFATAL, NOPARM,   27, "Missing ')'"},
-/* WARN_QUOTEMISS */    {WARNING,  NOPARM,    9, "Warning: missing '\"'"},
-/* ERR_QUOTEMISS */     {NONFATAL, NOPARM,    9, "Missing '\"'"},
-/* ERR_HASHMISS */      {NONFATAL, NOPARM,   45, "Missing '#'"},
-/* ERR_ENDIF */         {NONFATAL, NOPARM,   49, "Cannot find matching 'ENDIF' for this 'IF' or 'ELSE'"},
-/* ERR_ENDWHILE */      {NONFATAL, NOPARM,   49, "Cannot find 'ENDWHILE' matching this 'WHILE'"},
-/* ERR_ENDCASE */       {NONFATAL, NOPARM,   47, "Cannot find 'ENDCASE'"},
-/* ERR_UNTIL */         {NONFATAL, NOPARM,   43, "Cannot find 'UNTIL' matching this 'REPEAT'"},
-/* ERR_NEXT */          {NONFATAL, NOPARM,   32, "Cannot find 'NEXT' matching this 'FOR'"},
 /* ERR_MULTINEXT */     {WARNING,  NOPARM,    0, "'EXIT FOR' encountered an incompatible 'NEXT' statement"},
-/* ERR_EXITFOR */       {NONFATAL, NOPARM,   32, "'EXIT FOR' statement"},
-/* ERR_OFMISS */        {NONFATAL, NOPARM,   48, "'OF' missing"},
-/* ERR_TOMISS */        {NONFATAL, NOPARM,   36, "'TO' missing"},
-/* ERR_CORPNEXT */      {NONFATAL, NOPARM,   27, "',' or ')' expected"},
-/* ERR_NOTWHILE */      {NONFATAL, NOPARM,   46, "Not in a 'WHILE' loop"},
-/* ERR_NOTREPEAT */     {NONFATAL, NOPARM,   43, "Not in a 'REPEAT' loop"},
-/* ERR_NOTFOR */        {NONFATAL, NOPARM,   32, "Not in a 'FOR' loop"},
-/* ERR_DIVZERO */       {NONFATAL, NOPARM,   18, "Division by zero"},
-/* ERR_NEGROOT */       {NONFATAL, NOPARM,   21, "Tried to take square root of a negative number"},
-/* ERR_LOGRANGE */      {NONFATAL, NOPARM,   22, "Tried to take log of zero or a negative number"},
-/* ERR_RANGE */         {NONFATAL, NOPARM,   20, "Number is out of range"},
-/* ERR_ONRANGE */       {NONFATAL, INTEGER,  40, "'ON' statement index value of %d is out of range"},
-/* ERR_ARITHMETIC */    {NONFATAL, NOPARM,   20, "Floating point exception"},
-/* ERR_PRECISION */     {WARNING,  NOPARM,    0, "Warning: Precision lost in floating-point conversion"},
-/* ERR_STRINGLEN */     {NONFATAL, NOPARM,   19, "Character string is too long"},
 /* ERR_BADOPER */       {NONFATAL, NOPARM,    0, "Unrecognisable operand"},
+/* ERR_NOROOM */        {FATAL,    NOPARM,    0, "The interpreter has run out of memory"},
+/* ERR_STACKFULL */     {FATAL,    NOPARM,    0, "Arithmetic stack overflow"},
+/* ERR_OPSTACK */       {FATAL,    NOPARM,    0, "Expression is too complex to evaluate"},
+/* ERR_LOMEMFIXED */    {NONFATAL, NOPARM,    0, "LOMEM cannot be changed in a PROC or FN"},
+/* ERR_HIMEMFIXED */    {NONFATAL, NOPARM,    0, "HIMEM cannot be changed in a PROC, FN or any other program structure"},
+/* ERR_BADTRACE */      {NONFATAL, NOPARM,    0, "Invalid option found after 'TRACE'"},
+/* ERR_LIBSIZE */       {FATAL,    STRING,    0, "There is not enough memory to load library '%s'"},
+/* ERR_NOLIBLOC */      {NONFATAL, NOPARM,    0, "'LIBRARY LOCAL' can only be used at the start of a library"},
+/* ERR_FILENAME */      {NONFATAL, NOPARM,    0, "File name missing"},
+/* ERR_EDITFAIL */      {FATAL,    STRING,    0, "Edit session failed (%s)"},
+/* ERR_NOGZIP */        {FATAL,    NOPARM,    0, "This build of the interpreter does not support gzipped programs"},
+/* ERR_BROKEN */        {FATAL,    INTSTR,    0, "The interpreter has gone wrong at line %d in %s"},
+/* ERR_OSFULL */        {FATAL,    INTSTR,    0, "The interpreter was unable to claim memory at line %d in %s"},
+/* ERR_COMMAND */       {FATAL,    NOPARM,    0, "This Basic command cannot be used in a running program"},
+/* ERR_RENUMBER */      {FATAL,    NOPARM,    0, "Line number went outside the range 0..65279 when renumbering program"},
+/* WARN_LINENO */       {WARNING,  NOPARM,    0, "Warning: line number is outside the range 0..65279"},
+/* WARN_LINEMISS */     {WARNING,  INTEGER,   0, "Warning: could not find line %d when renumbering program"},
+/* WARN_RPMISS */       {WARNING,  NOPARM,    0, "Warning: number of '(' in line exceeds the number of ')'"},
+/* WARN_RPAREN */       {WARNING,  NOPARM,    0, "Warning: number of '(' in line is less than the number of ')'"},
+/* WARN_PARNEST */      {WARNING,  NOPARM,    0, "Warning: '(' and ')' are nested incorrectly"},
+/* WARN_FUNNYFLOAT */   {WARNING,  NOPARM,    0, "Warning: floating point number format is not known"},
+/* WARN_LIBLOADED */    {WARNING,  STRING,    0, "Library '%s' has already been loaded. Command ignored"},
+/* WARN_BADHIMEM */     {WARNING,  NOPARM,    0, "Value of HIMEM must be in the range END to end of the Basic workspace"},
+/* WARN_BADLOMEM */     {WARNING,  NOPARM,    0, "Value of LOMEM must be in the range TOP to end of the Basic workspace"},
+/* WARN_BADPAGE */      {WARNING,  NOPARM,    0, "Value of PAGE must lie in the Basic workspace"},
+/* WARN_BADTOKEN */     {WARNING,  NOPARM,    0, "Value entered is not a legal token value"},
+/* ERR_EQMISS */        {NONFATAL, NOPARM,    4, "Mistake"},
 /* ERR_TYPENUM */       {NONFATAL, NOPARM,    6, "Type mismatch: number wanted"},
 /* ERR_TYPESTR */       {NONFATAL, NOPARM,    6, "Type mismatch: string wanted"},
 /* ERR_PARMNUM */       {NONFATAL, INTEGER,   6, "Type mismatch: number wanted for PROC/FN parameter no. %d"},
@@ -535,44 +511,80 @@ static detail errortable [] = {
 /* ERR_NOSWAP */        {NONFATAL, NOPARM,    6, "Type mismatch: cannot swap variables or arrays of different types"},
 /* ERR_UNSUITABLEVAR */ {NONFATAL, NOPARM,    6, "Type mismatch: unsuitable variable type for operation"},
 /* ERR_BADARITH */      {NONFATAL, NOPARM,    6, "Arithmetic operations cannot be performed on these operands"},
-/* ERR_BADEXPR */       {NONFATAL, NOPARM,   16, "Syntax error in expression"},
-/* ERR_RETURN */        {NONFATAL, NOPARM,   38, "RETURN encountered outside a subroutine"},
-/* ERR_NOTAPROC */      {NONFATAL, NOPARM,   30, "Functions cannot be used as PROCs"},
-/* ERR_NOTAFN */        {NONFATAL, NOPARM,   30, "PROCs cannot be used as functions"},
-/* ERR_ENDPROC */       {NONFATAL, NOPARM,   13, "ENDPROC encountered outside a PROC"},
+/* ERR_BADBITWISE */    {NONFATAL, NOPARM,    6, "Bitwise operations cannot be performed on these operands"},
 /* ERR_FNRETURN */      {NONFATAL, NOPARM,    7, "'=' (function return) encountered outside a function"},
+/* ERR_QUOTEMISS */     {NONFATAL, NOPARM,    9, "Missing '\"'"},
+/* WARN_QUOTEMISS */    {WARNING,  NOPARM,    9, "Warning: missing '\"'"},
+/* ERR_NEGDIM */        {NONFATAL, STRING,   10, "Dimension of array '%s)' is negative"},
+/* ERR_NEGBYTEDIM */    {NONFATAL, STRING,   10, "Dimension of byte array '%s' is negative"},
+/* ERR_DIMCOUNT */      {NONFATAL, STRING,   10, "Array '%s)' has too many dimensions"},
+/* ERR_DUPLDIM */       {NONFATAL, STRING,   10, "Array '%s)' has already been created"},
+/* ERR_BADDIM */        {NONFATAL, STRING,   11, "There is not enough memory to create array '%s)'"},
+/* ERR_BADBYTEDIM */    {NONFATAL, STRING,   11, "There is not enough memory to create a byte array"},
 /* ERR_LOCAL */         {NONFATAL, NOPARM,   12, "LOCAL found outside a PROC or FN"},
-/* ERR_DATA */          {NONFATAL, NOPARM,   42, "There are no more 'DATA' statements to read"},
-/* ERR_NOROOM */        {FATAL,    NOPARM,    0, "The interpreter has run out of memory"},
-/* ERR_WHENCOUNT */     {NONFATAL, NOPARM,   47, "'CASE' statement has too many 'WHEN' clauses"},
-/* ERR_SYSCOUNT */      {NONFATAL, NOPARM,   51, "'SYS' statement has too many parameters"},
-/* ERR_STACKFULL */     {FATAL,    NOPARM,    0, "Arithmetic stack overflow"},
-/* ERR_OPSTACK */       {FATAL,    NOPARM,    0, "Expression is too complex to evaluate"},
-/* WARN_BADHIMEM */     {WARNING,  NOPARM,    0, "Value of HIMEM must be in the range END to end of the Basic workspace"},
-/* WARN_BADLOMEM */     {WARNING,  NOPARM,    0, "Value of LOMEM must be in the range TOP to end of the Basic workspace"},
-/* WARN_BADPAGE */      {WARNING,  NOPARM,    0, "Value of PAGE must lie in the Basic workspace"},
-/* ERR_LOMEMFIXED */    {NONFATAL, NOPARM,    0, "LOMEM cannot be changed in a PROC or FN"}, // need to check what uses this
-/* ERR_HIMEMFIXED */    {NONFATAL, NOPARM,    0, "HIMEM cannot be changed in a PROC, FN or any other program structure"},
-/* ERR_BADTRACE */      {NONFATAL, NOPARM,    0, "Invalid option found after 'TRACE'"},
-/* ERR_ERRNOTOP */      {NONFATAL, NOPARM,   54, "'RESTORE ERROR' information is not the top item on the Basic stack"},
-/* ERR_DATANOTOP */     {NONFATAL, NOPARM,   54, "'RESTORE DATA' information is not the top item on the Basic stack"},
+/* ERR_ENDPROC */       {NONFATAL, NOPARM,   13, "ENDPROC encountered outside a PROC"},
+/* ERR_ARRAYMISS */     {NONFATAL, STRING,   14, "Cannot find array '%s)'"},
+/* ERR_NODIMS */        {NONFATAL, STRING,   14, "The dimensions of array '%s)' have not been defined"},
+/* ERR_BADINDEX */      {NONFATAL, INTSTR,   15, "Array index value of %d is out of range in reference to '%s)'"},
+/* ERR_INDEXCO */       {NONFATAL, STRING,   15, "Number of array indexes in reference to '%s)' is wrong"},
+/* ERR_DIMRANGE */      {NONFATAL, NOPARM,   15, "The dimension number in call to 'DIM()' is out of range"},
+/* ERR_SYNTAX */        {NONFATAL, NOPARM,   16, "Syntax error"},
+/* ERR_BADEXPR */       {NONFATAL, NOPARM,   16, "Syntax error in expression"},
+/* ERR_ESCAPE */        {NONFATAL, NOPARM,   17, "Escape"},
+/* ERR_DIVZERO */       {NONFATAL, NOPARM,   18, "Division by zero"},
+/* ERR_STRINGLEN */     {NONFATAL, NOPARM,   19, "Character string is too long"},
+/* ERR_RANGE */         {NONFATAL, NOPARM,   20, "Number is out of range"},
+/* ERR_ARITHMETIC */    {NONFATAL, NOPARM,   20, "Floating point exception"},
+/* ERR_HEXOVERFLOW */   {NONFATAL, NOPARM,   20, "Value out of range for current hexadecimal mode"},
+/* WARN_EXPOFLO */      {WARNING,  NOPARM,   20, "Warning: exponent is too large"},
+/* ERR_NEGROOT */       {NONFATAL, NOPARM,   21, "Tried to take square root of a negative number"},
+/* ERR_LOGRANGE */      {NONFATAL, NOPARM,   22, "Tried to take log of zero or a negative number"},
 /* ERR_BADMODESC */     {NONFATAL, NOPARM,   25, "Screen mode descriptor is invalid"},
 /* ERR_BADMODE */       {NONFATAL, NOPARM,   25, "Screen mode is not available"},
-/* WARN_LIBLOADED */    {WARNING,  STRING,    0, "Library '%s' has already been loaded. Command ignored"},
+/* ERR_VARMISS */       {NONFATAL, STRING,   26, "Cannot find variable '%s'"},
+/* ERR_COMISS */        {NONFATAL, NOPARM,   27, "Missing ','"},
+/* ERR_LPMISS */        {NONFATAL, NOPARM,   27, "Missing '('"},
+/* ERR_RPMISS */        {NONFATAL, NOPARM,   27, "Missing ')'"},
+/* ERR_CORPNEXT */      {NONFATAL, NOPARM,   27, "',' or ')' expected"},
+/* WARN_BADHEX */       {WARNING,  NOPARM,   28, "Warning: bad hexadecimal constant"},
+/* WARN_BADBIN */       {WARNING,  NOPARM,   28, "Warning: bad binary constant"},
+/* ERR_FNMISS */        {NONFATAL, STRING,   29, "Cannot find function 'FN%s'"},
+/* ERR_PROCMISS */      {NONFATAL, STRING,   29, "Cannot find procedure 'PROC%s'"},
+/* ERR_NOTAPROC */      {NONFATAL, NOPARM,   30, "Functions cannot be used as PROCs"},
+/* ERR_NOTAFN */        {NONFATAL, NOPARM,   30, "PROCs cannot be used as functions"},
+/* ERR_TOOMANY */       {NONFATAL, BSTRING,  31, "There are too many parameters in the call to '%s'"},
+/* ERR_NOTENUFF */      {NONFATAL, BSTRING,  31, "There are not enough parameters in the call to '%s'"},
+/* ERR_NEXT */          {NONFATAL, NOPARM,   32, "Cannot find 'NEXT' matching this 'FOR'"},
+/* ERR_EXITFOR */       {NONFATAL, NOPARM,   32, "'EXIT FOR' statement"},
+/* ERR_NOTFOR */        {NONFATAL, NOPARM,   32, "Not in a 'FOR' loop"},
+/* ERR_TOMISS */        {NONFATAL, NOPARM,   36, "'TO' missing"},
+/* ERR_RETURN */        {NONFATAL, NOPARM,   38, "RETURN encountered outside a subroutine"},
+/* ERR_ONRANGE */       {NONFATAL, INTEGER,  40, "'ON' statement index value of %d is out of range"},
+/* ERR_LINEMISS */      {NONFATAL, INTEGER,  41, "Cannot find line %d"},
+/* ERR_DATA */          {NONFATAL, NOPARM,   42, "There are no more 'DATA' statements to read"},
+/* ERR_UNTIL */         {NONFATAL, NOPARM,   43, "Cannot find 'UNTIL' matching this 'REPEAT'"},
+/* ERR_NOTREPEAT */     {NONFATAL, NOPARM,   43, "Not in a 'REPEAT' loop"},
+/* ERR_HASHMISS */      {NONFATAL, NOPARM,   45, "Missing '#'"},
+/* ERR_NOTWHILE */      {NONFATAL, NOPARM,   46, "Not in a 'WHILE' loop"},
+/* ERR_WHENCOUNT */     {NONFATAL, NOPARM,   47, "'CASE' statement has too many 'WHEN' clauses"},
+/* ERR_ENDCASE */       {NONFATAL, NOPARM,   47, "Cannot find 'ENDCASE'"},
+/* ERR_OFMISS */        {NONFATAL, NOPARM,   48, "'OF' missing"},
+/* ERR_ENDIF */         {NONFATAL, NOPARM,   49, "Cannot find matching 'ENDIF' for this 'IF' or 'ELSE'"},
+/* ERR_ENDWHILE */      {NONFATAL, NOPARM,   49, "Cannot find 'ENDWHILE' matching this 'WHILE'"},
+/* ERR_SYSCOUNT */      {NONFATAL, NOPARM,   51, "'SYS' statement has too many parameters"},
+/* ERR_ERRNOTOP */      {NONFATAL, NOPARM,   54, "'RESTORE ERROR' information is not the top item on the Basic stack"},
+/* ERR_DATANOTOP */     {NONFATAL, NOPARM,   54, "'RESTORE DATA' information is not the top item on the Basic stack"},
+/* ERR_BADVARPROCNAME */{NONFATAL, NOPARM,  126, "Variable or procedure/function name too long"},
+/* ERR_BADPROCFNNAME */ {NONFATAL, INTEGER, 127, "Procedure or function name found at line %d is too long"},
 /* ERR_NOLIB */         {NONFATAL, STRING,  214, "Cannot find library '%s'"},
-/* ERR_LIBSIZE */       {FATAL,    STRING,    0, "There is not enough memory to load library '%s'"},
-/* ERR_NOLIBLOC */      {NONFATAL, NOPARM,    0, "'LIBRARY LOCAL' can only be used at the start of a library"},
-/* ERR_FILENAME */      {NONFATAL, NOPARM,    0, "File name missing"},
+/* ERR_DIRNOTFOUND */   {NONFATAL, NOPARM,  214, "Directory not found or could not be selected"},
+/* ERR_ADDRESS */       {NONFATAL, NOPARM,  242, "Address is out of range for given variable type"},
+/* ERR_OSCLIFAIL */     {NONFATAL, STRING,  254, "OSCLI failed (%s)"},
+/* ERR_SWINAMENOTKNOWN*/{NONFATAL, NOPARM,  486, "SWI name '%s' not known"},
+/* ERR_SWINUMNOTKNOWN */{NONFATAL, INTEGER, 486, "SWI &%llX not known"},
+/* ERR_PRINTER */       {NONFATAL, NOPARM,  509, "Unable to connect to printer"},
+/* ERR_ADDREXCEPT */    {NONFATAL, NOPARM,  0x80000003, "Address exception"},
 // Filing system errors:
-/* ERR_NOTFOUND */      {NONFATAL, STRING,  214, "Cannot find file '%s'"},
-/* ERR_OPENWRITE */     {NONFATAL, STRING,  193, "Cannot open file '%s' for output"},
-/* ERR_OPENIN */        {NONFATAL, NOPARM,  193, "Cannot write to file as it has been opened for input only"},
-/* ERR_CANTREAD */      {NONFATAL, NOPARM,  189, "Unable to read from file"},
-/* ERR_CANTWRITE */     {NONFATAL, NOPARM,  193, "Unable to write to file"},
-/* ERR_HITEOF */        {NONFATAL, NOPARM,  223, "Have reached end of file"},
-/* ERR_READFAIL */      {NONFATAL, STRING,  189, "Could not read file '%s'"},
-/* ERR_NOTCREATED */    {NONFATAL, STRING,  192, "Could not create file '%s'"},
-/* ERR_WRITEFAIL */     {NONFATAL, STRING,  202, "Could not finish writing to file '%s'"},
 #ifdef TARGET_RISCOS
 /* ERR_FILEIO */        {FATAL,    STRING,    0, "%s"},
 /* ERR_CMDFAIL */       {NONFATAL, STRING,  254, "%s"},
@@ -580,61 +592,47 @@ static detail errortable [] = {
 /* ERR_FILEIO */        {FATAL,    STRING,    0, "Hit problem with file '%s'"},
 /* ERR_CMDFAIL */       {NONFATAL, NOPARM,  254, "OS command failed"},
 #endif
-/* ERR_UNKNOWN */       {FATAL,    INTEGER, 244, "Unexpected signal (&%x) received"},
-/* ERR_BADHANDLE */     {NONFATAL, NOPARM,  222, "Handle is invalid or file associated with it has been closed"},
 /* ERR_SETPTRFAIL */    {FATAL,    NOPARM,    0, "The file pointer cannot be changed"},
 /* ERR_GETPTRFAIL */    {FATAL,    NOPARM,    0, "The file pointer's value cannot be found"},
 /* ERR_GETEXTFAIL */    {FATAL,    NOPARM,    0, "The size of the file cannot be found"},
-/* ERR_MAXHANDLE */     {NONFATAL, NOPARM,  192, "The maximum allowed number of files is already open"},
-/* ERR_INVALIDFNAME */  {NONFATAL, NOPARM,  253, "Invalid file name"},
 /* ERR_NOMEMORY */      {FATAL,    NOPARM,    0, "Amount of memory requested exceeds what is available"},
-//
-/* ERR_BROKEN */        {FATAL,    INTSTR,    0, "The interpreter has gone wrong at line %d in %s"},
-/* ERR_COMMAND */       {FATAL,    NOPARM,    0, "This Basic command cannot be used in a running program"},
-/* ERR_RENUMBER */      {FATAL,    NOPARM,    0, "Line number went outside the range 0..65279 when renumbering program"},
-/* WARN_LINENO */       {WARNING,  NOPARM,    0, "Warning: line number is outside the range 0..65279"},
-/* WARN_LINEMISS */     {WARNING,  INTEGER,   0, "Warning: could not find line %d when renumbering program"},
-/* WARN_RPMISS */       {WARNING,  NOPARM,    0, "Warning: number of '(' in line exceeds the number of ')'"},
-/* WARN_RPAREN */       {WARNING,  NOPARM,    0, "Warning: number of '(' in line is less than the number of ')'"},
-/* WARN_PARNEST */      {WARNING,  NOPARM,    0, "Warning: '(' and ')' are nested incorrectly"},
-//
-/* ERR_EDITFAIL */      {FATAL,    STRING,    0, "Edit session failed (%s)"},
-/* ERR_OSCLIFAIL */     {NONFATAL, STRING,  254, "OSCLI failed (%s)"},
-/* ERR_NOGZIP */        {FATAL,    NOPARM,    0, "This build of the interpreter does not support gzipped programs"},
-/* WARN_FUNNYFLOAT */   {WARNING,  NOPARM,    0, "Warning: floating point number format is not known"},
-/* ERR_SWINAMENOTKNOWN*/{NONFATAL, NOPARM,  486, "SWI name '%s' not known"},
-/* ERR_SWINUMNOTKNOWN */{NONFATAL, INTEGER, 486, "SWI &%llX not known"},
-/* ERR_DIRNOTFOUND */   {NONFATAL, NOPARM,  214, "Directory not found or could not be selected"},
-/* ERR_BADBITWISE */    {NONFATAL, NOPARM,    6, "Bitwise operations cannot be performed on these operands"},
-/* ERR_ADDREXCEPT */    {NONFATAL, NOPARM,  243, "Address exception"},
-/* ERR_PRINTER */       {NONFATAL, NOPARM,  509, "Unable to connect to printer"},
-/* ERR_BADVARPROCNAME */{NONFATAL, NOPARM,  126, "Variable or procedure/function name too long"},
-/* ERR_BADPROCFNNAME */ {NONFATAL, INTEGER, 127, "Procedure or function name found at line %d is too long"},
-//
+/* ERR_CANTREAD */      {NONFATAL, NOPARM,  189, "Unable to read from file"},
+/* ERR_READFAIL */      {NONFATAL, STRING,  189, "Could not read file '%s'"},
+/* ERR_NOTCREATED */    {NONFATAL, STRING,  192, "Could not create file '%s'"},
+/* ERR_MAXHANDLE */     {NONFATAL, NOPARM,  192, "The maximum allowed number of files is already open"},
+/* ERR_OPENWRITE */     {NONFATAL, STRING,  193, "Cannot open file '%s' for output"},
+/* ERR_OPENIN */        {NONFATAL, NOPARM,  193, "Cannot write to file as it has been opened for input only"},
+/* ERR_CANTWRITE */     {NONFATAL, NOPARM,  193, "Unable to write to file"},
+/* ERR_WRITEFAIL */     {NONFATAL, STRING,  202, "Could not finish writing to file '%s'"},
+/* ERR_NOTFOUND */      {NONFATAL, STRING,  214, "Cannot find file '%s'"},
+/* ERR_BADHANDLE */     {NONFATAL, NOPARM,  222, "Handle is invalid or file associated with it has been closed"},
+/* ERR_HITEOF */        {NONFATAL, NOPARM,  223, "Have reached end of file"},
+/* ERR_UNKNOWN */       {FATAL,    INTEGER, 244, "Unexpected signal (&%x) received"},
+/* ERR_INVALIDFNAME */  {NONFATAL, NOPARM,  253, "Invalid file name"},
 // OSCLI (command line) errors:
-/* ERR_BADCOMMAND */    {NONFATAL, NOPARM,  254, "Bad command"},
-/* ERR_BADSTRING */     {NONFATAL, NOPARM,  253, "Bad string"},
-/* ERR_BADNUMBER */     {NONFATAL, NOPARM,  252, "Bad number"},
-/* ERR_BADKEY */        {NONFATAL, NOPARM,  251, "Bad key"},
-/* ERR_KEYINUSE */      {NONFATAL, NOPARM,  250, "Key in use"},
-/* ERR_MOSVERSION */    {NONFATAL, NOPARM,  247, "Matrix Brandy MOS V" BRANDY_MAJOR "." BRANDY_MINOR "." BRANDY_PATCHLEVEL " (" BRANDY_DATE ")"},
 /* ERR_BADSYNTAX */     {NONFATAL, STRING,  220, "Syntax: %s"},
+/* ERR_MOSVERSION */    {NONFATAL, NOPARM,  247, "Matrix Brandy MOS V" BRANDY_MAJOR "." BRANDY_MINOR "." BRANDY_PATCHLEVEL " (" BRANDY_DATE ")"},
+/* ERR_KEYINUSE */      {NONFATAL, NOPARM,  250, "Key in use"},
+/* ERR_BADKEY */        {NONFATAL, NOPARM,  251, "Bad key"},
+/* ERR_BADNUMBER */     {NONFATAL, NOPARM,  252, "Bad number"},
+/* ERR_BADSTRING */     {NONFATAL, NOPARM,  253, "Bad string"},
+/* ERR_BADCOMMAND */    {NONFATAL, NOPARM,  254, "Bad command"},
 //
 // Network errors
-/* ERR_NET_CONNREFUSED*/{NONFATAL, NOPARM,  165, "Connection refused"},                  // 'No reply'
-/* ERR_NET_NOTFOUND */  {NONFATAL, NOPARM,  213, "Host not found"},                      // 'Disk not present'
-/* ERR_NET_MAXSOCKETS */{NONFATAL, NOPARM,  192, "The maximum allowed number of sockets is already open"},
 /* ERR_NET_NOTSUPP */   {NONFATAL, NOPARM,  157, "Network operation not supported"},     // 'Unsupported operation'
+/* ERR_NET_CONNREFUSED*/{NONFATAL, NOPARM,  165, "Connection refused"},                  // 'No reply'
+/* ERR_NET_MAXSOCKETS */{NONFATAL, NOPARM,  192, "The maximum allowed number of sockets is already open"},
+/* ERR_NET_NOTFOUND */  {NONFATAL, NOPARM,  213, "Host not found"},                      // 'Disk not present'
 /* ERR_NO_RPI_GPIO */   {NONFATAL, NOPARM,  510, "Raspberry Pi GPIO not available"},
 //
 // Dynamic Linker errors
 /* ERR_DL_NODL */       {FATAL,    NOPARM,    0, "Dynamic Linking not available"},
 /* ERR_DL_NOSYM */      {FATAL,    STRING,    0, "%s"},
 //
-/* ERR_BAD_OSFILE */    {NONFATAL, NOPARM, 1026, "Bad OSFile call"},
-/* ERR_FILELOCKED */    {NONFATAL, NOPARM,  195, "This item is locked to stop changes being made to it"},
 /* ERR_DIRNOTEMPTY */   {NONFATAL, NOPARM,  180, "Directory not empty"},
 /* ERR_NODIR */         {NONFATAL, NOPARM,  189, "Unable to create directory"},
+/* ERR_FILELOCKED */    {NONFATAL, NOPARM,  195, "This item is locked to stop changes being made to it"},
+/* ERR_BAD_OSFILE */    {NONFATAL, NOPARM, 1026, "Bad OSFile call"},
 //
 // DO NOT PUT ANYTHING BELOW THIS LINE - THIS MUST BE THE LAST ERROR
 /* HIGHERROR */         {FATAL,    NOPARM,    0, "You should never see this"} /* ALWAYS leave this as the last error */
@@ -850,7 +848,7 @@ void error(int32 errnumber, ...) {
 
 /* This causes a segfault on an error, to stop gdb in its tracks.
 ** UGLY UGLY hack. Use with compilation option -g to allow a stack
-** backtrace to see exactly where an error condition was raised. */
+** backtrace to see exactly how an error condition was raised. */
 #ifdef BORKONERROR
   char *collapse = NULL; /* debug hack */
 
@@ -940,7 +938,7 @@ void show_error(int32 number, char *text) {
 void set_error(void) {
   DEBUGFUNCMSGIN;
   basicvars.error_handler.current = basicvars.current;
-  basicvars.error_handler.stacktop = basicvars.safestack.bytesp; /* get_safestack */
+  basicvars.error_handler.stacktop = basicvars.safestack.bytesp;
   basicvars.error_handler.islocal = FALSE;
 #ifdef DEBUG
   if (basicvars.debug_flags.debug) fprintf(stderr, "Set up ON ERROR handler at %p,  stack = %p\n",
