@@ -34,7 +34,6 @@ extern void exec_close(void);
 extern void exec_cls(void);
 extern void exec_colour(void);
 extern void exec_draw(void);
-extern void exec_drawby(void);
 extern void exec_ellipse(void);
 extern void exec_envelope(void);
 extern void exec_fill(void);
@@ -45,13 +44,10 @@ extern void exec_line(void);
 extern void exec_mode(void);
 extern void exec_mouse(void);
 extern void exec_move(void);
-extern void exec_moveby(void);
 extern void exec_off(void);
 extern void exec_origin(void);
 extern void exec_plot(void);
 extern void exec_point(void);
-extern void exec_pointby(void);
-extern void exec_pointto(void);
 extern void exec_print(void);
 extern void exec_rectangle(void);
 extern void exec_sound(void);
