@@ -28,6 +28,8 @@ extern int32 net_bget(int handle);
 extern boolean net_eof(int handle);
 extern int net_bput(int handle, int32 value);
 extern int net_bputstr(int handle, char *string, int32 length);
+#ifndef BRANDY_NOVERCHECK
 extern int checkfornewer(void);
+#endif
 #endif /* NONET */
 #endif /* BRANDY_NET_H */
