@@ -35,10 +35,14 @@
 #define BRANDY_NAME  "Matrix"
 #define BRANDY_MAJOR "1"
 #define BRANDY_MINOR "23"
-#define BRANDY_PATCHLEVEL "5"
-#define BRANDY_DATE       "06 Apr 2025"
+#define BRANDY_PATCHLEVEL "6"
+#define BRANDY_DATE       "19 Oct 2025"
 // #define BRANDY_PATCHDATE  "JGH191007"
 
+#ifdef BRANDY_RELEASE
+#undef DEBUG
+#endif
+
 /*
 ** DEFAULTSIZE and MINSIZE give the default and minimum Basic
 ** workspace sizes in bytes. DEFAULTSIZE is the amount of memory
@@ -433,7 +437,11 @@ typedef unsigned long int nativeuint;   /* 32 or 64-bit depending on architectur
 #ifdef BRANDY_RELEASE
 #define IDSTRING "Matrix Brandy BASIC VI version " BRANDY_MAJOR "." BRANDY_MINOR "." BRANDY_PATCHLEVEL "-Release (" BRANDY_OS "/" CPUTYPE SFX1 SFX2 ") " BRANDY_DATE
 #else
+#ifdef BRANDY_GITCOMMIT
 #define IDSTRING "Matrix Brandy BASIC VI version " BRANDY_MAJOR "." BRANDY_MINOR "." BRANDY_PATCHLEVEL "+dev (" BRANDY_OS "/" CPUTYPE SFX1 SFX2 ") " BRANDY_DATE "\r\n\nDevelopment snapshot at git " BRANDY_GITBRANCH ":" BRANDY_GITCOMMIT " (" BRANDY_GITDATE ")"
+#else
+#define IDSTRING "Matrix Brandy BASIC VI version " BRANDY_MAJOR "." BRANDY_MINOR "." BRANDY_PATCHLEVEL "+dev (" BRANDY_OS "/" CPUTYPE SFX1 SFX2 ") " BRANDY_DATE "\r\n\nDevelopment snapshot"
+#endif
 #endif /* BRANDY_RELEASE */
 #endif /* BRANDY_NODISPLAYOS */
 
